@@ -1,4 +1,4 @@
-## Copyright 2011-2013 Sebastian Gibb
+## Copyright 2011-2014 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquant for R and related languages.
@@ -17,30 +17,39 @@
 ## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
 
 ## intensityMatrix
-##  convert list of AbstractMassObject objects to a matrix
+##  converts a list of MassPeaks into an expression matrix
 ##
 ## params:
-##  l: list of AbstractMassObject objects
+##  peaks: list of MassPeaks objects
+##  spectra: list of MassSpectrum objects
 ##
 ## returns:
 ##  a matrix
 ##
-intensityMatrix <- function(l) {
+intensityMatrix <- function(peaks, spectra) {
 
-  ## test parameters
-  .stopIfNotIsMassObjectList(l)
+  ## test arguments
+  .stopIfNotIsMassPeaksList(peaks)
 
-  ## fetch all mass
-  mass <- sort(x=.unlist(lapply(l, function(x)x@mass)), method="quick")
-  uMass <- unique(mass)
+  m <- .as.matrix.MassObjectList(peaks)
 
-  ## build matrix
-  m <- do.call(rbind, lapply(l, function(x) {
-    return(x@intensity[match(x=uMass, table=x@mass, nomatch=NA)])}))
+  ## lookup corresponding intensity values in spectra for missing peaks
+  if (!missing(spectra)) {
+    .stopIfNotIsMassSpectrumList(spectra)
 
-  ## set column names
-  dimnames(m) <- list(NULL, c(uMass))
+    if (length(peaks) != length(spectra)) {
+      stop("Incompatible number of spectra!")
+    }
 
-  return(m)
+    isNa <- is.na(m)
+    uniqueMass <- as.double(colnames(m))
+
+    approxSpectra <- lapply(spectra, approxfun, yleft=0L, yright=0L)
+
+    for (i in seq_along(approxSpectra)) {
+      m[i, isNa[i, ]] <- approxSpectra[[i]](uniqueMass[isNa[i, ]])
+    }
+  }
+
+  m
 }
-
