@@ -34,13 +34,12 @@
          " is too small!", call.=FALSE)
   }
 
-  windowSize <- halfWindowSize*2L+1L
+  windowSize <- halfWindowSize * 2L + 1L
 
   if (windowSize > n) {
     stop(parentCall, " : ", sQuote("halfWindowSize"),
          " is too large!", call.=FALSE)
   }
 
-  return(TRUE)
+  TRUE
 }
-
