@@ -36,7 +36,7 @@
 ##
 .warpingFunctionLowess <- function(x, d, ...) {
   lo <- lowess(x=x, y=d, ...)
-  return(approxfun(x=lo$x, y=lo$y, rule=2L))
+  approxfun(x=lo$x, y=lo$y, rule=2L)
 }
 
 ## .warpingFunctionLinear
@@ -53,7 +53,7 @@
 .warpingFunctionLinear <- function(x, d, ...) {
   l <- lm(y ~ x1, data=list(x1=x, y=d), ...)
   co <- coef(l)
-  return(function(x) { return (co[1L]+x*co[2L]) })
+  function(x) { co[1L]+x*co[2L] }
 }
 
 ## .warpingFunctionQuadratic
@@ -70,7 +70,7 @@
 .warpingFunctionQuadratic <- function(x, d, ...) {
   l <- lm(y ~ x1+x2, data=list(x1=x, x2=x*x, y=d), ...)
   co <- coef(l)
-  return(function(x) { return (co[1L]+x*co[2L]+x*x*co[3L]) })
+  function(x) { co[1L]+x*co[2L]+x*x*co[3L] }
 }
 
 ## .warpingFunctionCubic
@@ -87,6 +87,5 @@
 .warpingFunctionCubic <- function(x, d, ...) {
   l <- lm(y ~ x1+x2+x3, data=list(x1=x, x2=x*x, x3=x*x*x, y=d), ...)
   co <- coef(l)
-  return(function(x) { return (co[1L]+x*co[2L]+x*x*co[3L]+x*x*x*co[4L]) })
+  function(x) { co[1L]+x*co[2L]+x*x*co[3L]+x*x*x*co[4L] }
 }
-
